@@ -70,12 +70,12 @@ my_ltostr(long v,char *str)
 /*                 "C=US O=gov"                       */ 
 /******************************************************/
 static void
-get_Name_type(node_asn *cert_def,node_asn *cert,char *root, char *answer)
+get_Name_type(ASN1_TYPE cert_def,ASN1_TYPE cert,char *root, char *answer)
 {
   int k,k2,result,len;
   char name[128],str[1024],str2[1024],name2[128],counter[5],name3[128];
   ASN1_TYPE value=ASN1_TYPE_EMPTY;
-  char errorDescription[MAX_ERROR_DESCRIPTION_SIZE];
+  char errorDescription[ASN1_MAX_ERROR_DESCRIPTION_SIZE];
 
   answer[0]=0;
   k=1;
@@ -114,10 +114,10 @@ get_Name_type(node_asn *cert_def,node_asn *cert,char *root, char *answer)
 			      &value);
 	  len = sizeof(str)-1;
 	  asn1_read_value(cert,name3,str,&len);
-      	  result=asn1_der_decoding(&value,str,len,errorDescription);
+	  result=asn1_der_decoding(&value,str,len,errorDescription);
 
 	  len = sizeof(str)-1;
-	  asn1_read_value(value,"",str,&len);  /* CHOICE */	  
+	  asn1_read_value(value,"",str,&len);  /* CHOICE */
 
 	  strcpy(name3,str);
 	  
@@ -188,13 +188,13 @@ get_Name_type(node_asn *cert_def,node_asn *cert,char *root, char *answer)
 /*   int *der_len: number of bytes of der string      */ 
 /******************************************************/
 static void
-create_CRL(node_asn *cert_def, unsigned char *der,int *der_len)
+create_CRL(ASN1_TYPE cert_def, unsigned char *der,int *der_len)
 {
   int result,k,len;
   unsigned char str[1024],*str2;
   ASN1_TYPE crl=ASN1_TYPE_EMPTY;
   ASN1_TYPE value=ASN1_TYPE_EMPTY;
-  char errorDescription[MAX_ERROR_DESCRIPTION_SIZE];
+  char errorDescription[ASN1_MAX_ERROR_DESCRIPTION_SIZE];
   int max_len;
 
   max_len=*der_len;
@@ -349,12 +349,12 @@ create_CRL(node_asn *cert_def, unsigned char *der,int *der_len)
 /*   int der_len: number of bytes of der string      */ 
 /******************************************************/
 static void
-get_CRL(node_asn *cert_def,unsigned char *der,int der_len)
+get_CRL(ASN1_TYPE cert_def,unsigned char *der,int der_len)
 {
   int result,len,start,end;
   unsigned char str[1024],str2[1024];
   ASN1_TYPE crl2=ASN1_TYPE_EMPTY;
-  char errorDescription[MAX_ERROR_DESCRIPTION_SIZE];
+  char errorDescription[ASN1_MAX_ERROR_DESCRIPTION_SIZE];
 
 
   asn1_create_element(cert_def,"PKIX1Implicit88.CertificateList",&crl2);
@@ -414,7 +414,7 @@ main(int argc,char *argv[])
   int result,der_len;
   unsigned char der[1024];
   ASN1_TYPE PKIX1Implicit88=ASN1_TYPE_EMPTY;
-  char errorDescription[MAX_ERROR_DESCRIPTION_SIZE];
+  char errorDescription[ASN1_MAX_ERROR_DESCRIPTION_SIZE];
 
   if(1)
     result=asn1_array2tree(pkix_asn1_tab,&PKIX1Implicit88,errorDescription);   
@@ -422,7 +422,7 @@ main(int argc,char *argv[])
     result=asn1_parser2tree("pkix.asn",&PKIX1Implicit88,errorDescription);
 
   if(result != ASN1_SUCCESS){
-    libtasn1_perror(result);
+    asn1_perror(result);
     printf("%s\n",errorDescription);
     exit(1);
   }
