@@ -1,5 +1,5 @@
 /*
- *      Copyright (C) 2004, 2006 Free Software Foundation
+ *      Copyright (C) 2004, 2006, 2008 Free Software Foundation
  *      Copyright (C) 2002  Fabio Fiorina
  *
  * This file is part of LIBTASN1.
@@ -46,7 +46,7 @@
 /* Return:                                            */
 /******************************************************/
 void
-_asn1_error_description_value_not_found (node_asn * node,
+_asn1_error_description_value_not_found (ASN1_TYPE  node,
 					 char *ErrorDescription)
 {
 
@@ -55,7 +55,7 @@ _asn1_error_description_value_not_found (node_asn * node,
 
   Estrcpy (ErrorDescription, ":: value of element '");
   _asn1_hierarchical_name (node, ErrorDescription + strlen (ErrorDescription),
-			   MAX_ERROR_DESCRIPTION_SIZE - 40);
+			   ASN1_MAX_ERROR_DESCRIPTION_SIZE - 40);
   Estrcat (ErrorDescription, "' not found");
 
 }
@@ -260,7 +260,7 @@ _asn1_objectid_der (unsigned char *str, unsigned char *der, int *der_len)
 
   max_len = *der_len;
 
-  temp = (char *) _asn1_alloca (strlen (str) + 2);
+  temp = (char *) _asn1_malloc (strlen (str) + 2);
   if (temp == NULL)
     return ASN1_MEM_ALLOC_ERROR;
 
@@ -312,7 +312,7 @@ _asn1_objectid_der (unsigned char *str, unsigned char *der, int *der_len)
     }
   *der_len += len_len;
 
-  _asn1_afree (temp);
+  _asn1_free (temp);
 
   if (max_len < (*der_len))
     return ASN1_MEM_ERROR;
@@ -371,10 +371,10 @@ asn1_bit_der (const unsigned char *str, int bit_len,
 /*   otherwise ASN1_SUCCESS.                          */
 /******************************************************/
 asn1_retCode
-_asn1_complete_explicit_tag (node_asn * node, unsigned char *der,
+_asn1_complete_explicit_tag (ASN1_TYPE  node, unsigned char *der,
 			     int *counter, int *max_len)
 {
-  node_asn *p;
+  ASN1_TYPE p;
   int is_tag_implicit, len2, len3;
   unsigned char temp[SIZEOF_UNSIGNED_INT];
 
@@ -444,10 +444,10 @@ _asn1_complete_explicit_tag (node_asn * node, unsigned char *der,
 /*   otherwise ASN1_SUCCESS.                          */
 /******************************************************/
 asn1_retCode
-_asn1_insert_tag_der (node_asn * node, unsigned char *der, int *counter,
+_asn1_insert_tag_der (ASN1_TYPE  node, unsigned char *der, int *counter,
 		      int *max_len)
 {
-  node_asn *p;
+  ASN1_TYPE p;
   int tag_len, is_tag_implicit;
   unsigned char class, class_implicit = 0, temp[SIZEOF_UNSIGNED_INT * 3 + 1];
   unsigned long tag_implicit = 0;
@@ -605,7 +605,7 @@ _asn1_insert_tag_der (node_asn * node, unsigned char *der, int *counter,
 /* Return:                                            */
 /******************************************************/
 void
-_asn1_ordering_set (unsigned char *der, int der_len, node_asn * node)
+_asn1_ordering_set (unsigned char *der, int der_len, ASN1_TYPE  node)
 {
   struct vet
   {
@@ -616,7 +616,7 @@ _asn1_ordering_set (unsigned char *der, int der_len, node_asn * node)
 
   int counter, len, len2;
   struct vet *first, *last, *p_vet, *p2_vet;
-  node_asn *p;
+  ASN1_TYPE p;
   unsigned char class, *temp;
   unsigned long tag;
 
@@ -636,7 +636,7 @@ _asn1_ordering_set (unsigned char *der, int der_len, node_asn * node)
   first = last = NULL;
   while (p)
     {
-      p_vet = (struct vet *) _asn1_alloca (sizeof (struct vet));
+      p_vet = (struct vet *) _asn1_malloc (sizeof (struct vet));
       if (p_vet == NULL)
 	return;
 
@@ -677,7 +677,7 @@ _asn1_ordering_set (unsigned char *der, int der_len, node_asn * node)
 	  if (p_vet->value > p2_vet->value)
 	    {
 	      /* change position */
-	      temp = (unsigned char *) _asn1_alloca (p_vet->end - counter);
+	      temp = (unsigned char *) _asn1_malloc (p_vet->end - counter);
 	      if (temp == NULL)
 		return;
 
@@ -686,7 +686,7 @@ _asn1_ordering_set (unsigned char *der, int der_len, node_asn * node)
 		      p2_vet->end - p_vet->end);
 	      memcpy (der + counter + p2_vet->end - p_vet->end, temp,
 		      p_vet->end - counter);
-	      _asn1_afree (temp);
+	      _asn1_free (temp);
 
 	      tag = p_vet->value;
 	      p_vet->value = p2_vet->value;
@@ -704,7 +704,7 @@ _asn1_ordering_set (unsigned char *der, int der_len, node_asn * node)
 	p_vet->prev->next = NULL;
       else
 	first = NULL;
-      _asn1_afree (p_vet);
+      _asn1_free (p_vet);
       p_vet = first;
     }
 }
@@ -719,7 +719,7 @@ _asn1_ordering_set (unsigned char *der, int der_len, node_asn * node)
 /* Return:                                            */
 /******************************************************/
 void
-_asn1_ordering_set_of (unsigned char *der, int der_len, node_asn * node)
+_asn1_ordering_set_of (unsigned char *der, int der_len, ASN1_TYPE  node)
 {
   struct vet
   {
@@ -729,7 +729,7 @@ _asn1_ordering_set_of (unsigned char *der, int der_len, node_asn * node)
 
   int counter, len, len2, change;
   struct vet *first, *last, *p_vet, *p2_vet;
-  node_asn *p;
+  ASN1_TYPE p;
   unsigned char *temp, class;
   unsigned long k, max;
 
@@ -750,7 +750,7 @@ _asn1_ordering_set_of (unsigned char *der, int der_len, node_asn * node)
   first = last = NULL;
   while (p)
     {
-      p_vet = (struct vet *) _asn1_alloca (sizeof (struct vet));
+      p_vet = (struct vet *) _asn1_malloc (sizeof (struct vet));
       if (p_vet == NULL)
 	return;
 
@@ -815,7 +815,7 @@ _asn1_ordering_set_of (unsigned char *der, int der_len, node_asn * node)
 	  if (change == 1)
 	    {
 	      /* change position */
-	      temp = (unsigned char *) _asn1_alloca (p_vet->end - counter);
+	      temp = (unsigned char *) _asn1_malloc (p_vet->end - counter);
 	      if (temp == NULL)
 		return;
 
@@ -824,7 +824,7 @@ _asn1_ordering_set_of (unsigned char *der, int der_len, node_asn * node)
 		      (p2_vet->end) - (p_vet->end));
 	      memcpy (der + counter + (p2_vet->end) - (p_vet->end), temp,
 		      (p_vet->end) - counter);
-	      _asn1_afree (temp);
+	      _asn1_free (temp);
 
 	      p_vet->end = counter + (p2_vet->end - p_vet->end);
 	    }
@@ -838,7 +838,7 @@ _asn1_ordering_set_of (unsigned char *der, int der_len, node_asn * node)
 	p_vet->prev->next = NULL;
       else
 	first = NULL;
-      _asn1_afree (p_vet);
+      _asn1_free (p_vet);
       p_vet = first;
     }
 }
@@ -874,7 +874,7 @@ asn1_retCode
 asn1_der_coding (ASN1_TYPE element, const char *name, void *ider, int *len,
 		 char *ErrorDescription)
 {
-  node_asn *node, *p, *p2;
+  ASN1_TYPE node, p, p2;
   char temp[SIZEOF_UNSIGNED_LONG_INT * 3 + 1];
   int counter, counter_old, len2, len3, tlen, move, max_len, max_len_old;
   asn1_retCode err;
@@ -913,7 +913,8 @@ asn1_der_coding (ASN1_TYPE element, const char *name, void *ider, int *len,
 	case TYPE_NULL:
 	  max_len--;
 	  if (max_len >= 0)
-	    der[counter++] = 0;
+	    der[counter] = 0;
+	  counter++;
 	  move = RIGHT;
 	  break;
 	case TYPE_BOOLEAN:
