@@ -1,5 +1,5 @@
 /*
- *      Copyright (C) 2006, 2007 Free Software Foundation
+ *      Copyright (C) 2006, 2007, 2008 Free Software Foundation
  *      Copyright (C) 2002 Fabio Fiorina
  *
  * This file is part of LIBTASN1.
@@ -73,7 +73,7 @@ main(int argc,char *argv[])
  int checkSyntaxOnly=0;
  ASN1_TYPE definitions=ASN1_TYPE_EMPTY;
  ASN1_TYPE structure=ASN1_TYPE_EMPTY;
- char errorDescription[MAX_ERROR_DESCRIPTION_SIZE];
+ char errorDescription[ASN1_MAX_ERROR_DESCRIPTION_SIZE];
  int asn1_result=ASN1_SUCCESS;
  unsigned char *der;
  int  der_len=0;
@@ -161,7 +161,7 @@ main(int argc,char *argv[])
    printf("asn1Decoding: %s\n",errorDescription);
    break;
  default:
-   printf("libtasn1 ERROR: %s\n",libtasn1_strerror(asn1_result));
+   printf("libtasn1 ERROR: %s\n",asn1_strerror(asn1_result));
  }
 
  if(asn1_result != ASN1_SUCCESS){
@@ -174,7 +174,7 @@ main(int argc,char *argv[])
 
  {
    size_t tmplen;
-   der = read_binary_file (inputFileDerName, &tmplen);
+   der = (unsigned char*) read_binary_file (inputFileDerName, &tmplen);
    der_len = tmplen;
  }
 
@@ -210,7 +210,7 @@ main(int argc,char *argv[])
 
 
  if(asn1_result != ASN1_SUCCESS){
-   printf("Structure creation: %s\n",libtasn1_strerror(asn1_result));
+   printf("Structure creation: %s\n",asn1_strerror(asn1_result));
    asn1_delete_structure(&definitions);
 
    free(inputFileAsnName);
@@ -221,7 +221,7 @@ main(int argc,char *argv[])
  }
 
  asn1_result=asn1_der_decoding(&structure,der,der_len,errorDescription);
- printf("\nDecoding: %s\n",libtasn1_strerror(asn1_result));
+ printf("\nDecoding: %s\n",asn1_strerror(asn1_result));
  if(asn1_result != ASN1_SUCCESS)
    printf("asn1Decoding: %s\n",errorDescription);
 
